<p align="center">
    <img src="https://github.com/bullbesh/reformer/blob/main/reformer/image/reformer.png" width="420" height="360">
</p>

<p align="center">
    <b>
        reformer
    </b>
</p>

<p align="center">
    Simple program that help you to reform any word from Cyrillan to Latin.
</p>

### Visualisation
```
Write your message here:

> Бабка в кедах

6A6KA B KEDAX
```

### Installation
Clone the repository
```
git clone https://github.com/bullbesh/reformer
```

Find correctly directory
```
cd reformer/reformer
```
And run
```
python main.py
```

### Motives
Everyone once wanted to (or wants now) to set a _cool_ nickname, but sometimes it's hard to come up with it yourself. reformer will do it quickly, for free and efficiently.

### License
[MIT License](https://github.com/bullbesh/reformer/blob/main/LICENSE)